@@ -31,10 +31,11 @@ from .utils import (
 
 
 requests.packages.urllib3.disable_warnings()
+logging.basicConfig()
 log = logging.getLogger(__name__)
 
 tls_session = requests.Session()
-tls_session.mount("https://", UseTlsAdapter())
+tls_session.mount("http://", UseTlsAdapter())
 
 
 class HttpClient(object):
